pub struct ArrayType {
pub ty: Type,
pub len: usize,
}Expand description
A fixed-size, homogenous vector type.
Fields
ty: Typelen: usizeImplementations
Sourceimpl ArrayType
impl ArrayType
Sourcepub fn new(ty: Type, len: usize) -> Self
pub fn new(ty: Type, len: usize) -> Self
Create a new ArrayType of length len and element type of ty
Sourcepub fn element_type(&self) -> &Type
pub fn element_type(&self) -> &Type
Get the element type of this array type
Sourcepub fn min_alignment(&self) -> usize
pub fn min_alignment(&self) -> usize
Returns the minimum alignment required by this type
Sourcepub fn size_in_bits(&self) -> usize
pub fn size_in_bits(&self) -> usize
Returns the size in bits of this array type