PointerType

Struct PointerType 

pub struct PointerType {
    pub addrspace: AddressSpace,
    pub pointee: Type,
}
A pointer to an object in memory

Fields

addrspace: AddressSpace

The address space used by pointers of this type.

pointee: Type

The type of value located at the pointed-to address

Implementations

Source

impl PointerType

pub fn new(pointee: Type) -> Self

Create a new byte-addressable pointer type to pointee

pub fn new_with_address_space(pointee: Type, addrspace: AddressSpace) -> Self

Create a new pointer type to pointee in addrspace

pub fn pointee(&self) -> &Type

Returns the type pointed to by pointers of this type

pub fn addrspace(&self) -> AddressSpace

Returns the address space of this pointer type

pub fn is_byte_pointer(&self) -> bool

Returns true if this pointer type represents a byte pointer