pub struct StructField {
pub index: u8,
pub align: u16,
pub offset: u32,
pub ty: Type,
}Expand description
This represents metadata about a field of a StructType
Fields
index: u8The index of this field in the final layout
align: u16The specified alignment for this field
offset: u32The offset of this field relative to the base of the struct
ty: TypeThe type of this field