pub struct StructType { /* private fields */ }Expand description
This represents a structured aggregate type
Implementations
Sourceimpl StructType
impl StructType
Sourcepub fn new<I: IntoIterator<Item = Type>>(fields: I) -> Self
pub fn new<I: IntoIterator<Item = Type>>(fields: I) -> Self
Create a new struct with default representation, i.e. a struct with representation of
TypeRepr::Packed(1).
Sourcepub fn new_with_repr<I: IntoIterator<Item = Type>>(
repr: TypeRepr,
fields: I,
) -> Self
pub fn new_with_repr<I: IntoIterator<Item = Type>>( repr: TypeRepr, fields: I, ) -> Self
Create a new struct with the given representation.
This function will panic if the rules of the given representation are violated.
Sourcepub fn min_alignment(&self) -> usize
pub fn min_alignment(&self) -> usize
Get the minimum alignment for this struct
Sourcepub fn size(&self) -> usize
pub fn size(&self) -> usize
Get the total size in bytes required to hold this struct, including alignment padding
Sourcepub fn get(&self, index: usize) -> &StructField
pub fn get(&self, index: usize) -> &StructField
Get the struct field at index, relative to declaration order.
Sourcepub fn fields(&self) -> &[StructField]
pub fn fields(&self) -> &[StructField]
Get the struct fields as a slice