pub struct PointerType {
pub addrspace: AddressSpace,
pub pointee: Type,
}Expand description
A pointer to an object in memory
Fields
addrspace: AddressSpaceThe address space used by pointers of this type.
pointee: TypeThe type of value located at the pointed-to address
Implementations
Sourceimpl PointerType
impl PointerType
Sourcepub fn new_with_address_space(pointee: Type, addrspace: AddressSpace) -> Self
pub fn new_with_address_space(pointee: Type, addrspace: AddressSpace) -> Self
Create a new pointer type to pointee in addrspace
Sourcepub fn addrspace(&self) -> AddressSpace
pub fn addrspace(&self) -> AddressSpace
Returns the address space of this pointer type
Sourcepub fn is_byte_pointer(&self) -> bool
pub fn is_byte_pointer(&self) -> bool
Returns true if this pointer type represents a byte pointer